<?php 
$translations = array(
'General_Locale' => 'da_DK.UTF-8',
'General_TranslatorName' => 'JSM',
'General_TranslatorEmail' => 'jsm@janz.dk',
'General_EnglishLanguageName' => 'Danish',
'General_OriginalLanguageName' => 'Dansk',
'General_HelloUser' => 'Hej, %s!',
'General_OpenSourceWebAnalytics' => 'Open source webstatistik',
'General_YourDashboard' => 'Kontrolpanel',
'General_API' => 'API',
'General_Widgets' => 'Widgets',
'General_Settings' => 'Indstillinger',
'General_GiveUsYourFeedback' => 'Tilbagemelding!',
'General_Unknown' => 'Ukendt',
'General_Required' => '%s påkrævet',
'General_Error' => 'Fejl',
'General_Warning' => 'Advarsel',
'General_BackToHomepage' => 'Tilbage til Piwik startside',
'General_Yes' => 'Ja',
'General_No' => 'Nej',
'General_Delete' => 'Slet',
'General_Edit' => 'Ændre',
'General_Ok' => 'OK',
'General_Close' => 'Luk',
'General_Logout' => 'Log af',
'General_Done' => 'Færdig',
'General_LoadingData' => 'Indlæser data...',
'General_Loading' => 'Indlæser...',
'General_ErrorRequest' => 'Oops&hellip; problemer, prøv igen.',
'General_Next' => 'Næste',
'General_Previous' => 'Forrige',
'General_Search' => 'Søg',
'General_Others' => 'Andre',
'General_Table' => 'Tabel',
'General_Piechart' => 'Cirkeldiagram',
'General_TagCloud' => 'Emne sky',
'General_VBarGraph' => 'Søjlediagram',
'General_Export' => 'Eksporter',
'General_ExportAsImage' => 'Eksporter som billede',
'General_SaveImageOnYourComputer' => 'Gem billede på computer, højreklik på billede og vælg "Gem billede som…"',
'General_Refresh' => 'Opdater siden',
'General_Visitors' => 'Besøgende',
'General_ColumnNbUniqVisitors' => 'Unikke besøgende',
'General_ColumnNbVisits' => 'Besøg',
'General_ColumnNbActions' => 'Handlinger',
'General_ColumnMaxActions' => 'Max handlinger i et besøg',
'General_ColumnSumVisitLength' => 'Total tid brugt af besøgende visitors (i sekunder)',
'General_ColumnLabel' => 'Etiket',
'General_ColumnActionsPerVisit' => 'Handlinger pr. besøg',
'General_ColumnAvgTimeOnSite' => 'Gennemsnitstid på netsted',
'General_ColumnBounceRate' => 'Afvisningsfrekvens',
'General_ColumnPageviews' => 'Sidevisninger',
'General_ColumnUniquePageviews' => 'Unikke sidevisninger',
'General_ColumnValuePerVisit' => 'Værdi pr. besøg',
'General_ColumnVisitsWithConversions' => 'Besøg med konverteringer',
'General_Save' => 'Gem',
'General_Website' => 'Side',
'General_NoDataForGraph' => 'Ingen data endnu',
'General_NoDataForTagCloud' => 'Ingen data for emnesky.',
'General_DisplayNormalTable' => 'Vis normal tabel',
'General_DisplayMoreData' => 'Vis flere data',
'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s er et åbent kodeprojekt (OS). %s Hvis du vil hjælpe, så se: %s Hvordan kan man bidrage til Piwik?%s.',
'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Du bruger en demo af %s; %shent%s fuld version! Se %s',
'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s er udkommet. %s Opdater nu!%s (se %s ændringer%s).',
'General_BackToPiwik' => 'Tilbage til Piwik',
'General_ShortMonth_1' => 'Jan',
'General_ShortMonth_2' => 'Feb',
'General_ShortMonth_3' => 'Mar',
'General_ShortMonth_4' => 'Apr',
'General_ShortMonth_5' => 'Maj',
'General_ShortMonth_6' => 'Jun',
'General_ShortMonth_7' => 'Jul',
'General_ShortMonth_8' => 'Aug',
'General_ShortMonth_9' => 'Sep',
'General_ShortMonth_10' => 'Okt',
'General_ShortMonth_11' => 'Nov',
'General_ShortMonth_12' => 'Dec',
'General_LongMonth_1' => 'Januar',
'General_LongMonth_2' => 'Februar',
'General_LongMonth_3' => 'Marts',
'General_LongMonth_4' => 'April',
'General_LongMonth_5' => 'Maj',
'General_LongMonth_6' => 'Juni',
'General_LongMonth_7' => 'Juli',
'General_LongMonth_8' => 'August',
'General_LongMonth_9' => 'September',
'General_LongMonth_10' => 'Oktober',
'General_LongMonth_11' => 'November',
'General_LongMonth_12' => 'December',
'General_ShortDay_1' => 'Man',
'General_ShortDay_2' => 'Tir',
'General_ShortDay_3' => 'Ons',
'General_ShortDay_4' => 'Tor',
'General_ShortDay_5' => 'Fre',
'General_ShortDay_6' => 'Lør',
'General_ShortDay_7' => 'Søn',
'General_LongDay_1' => 'Mandag',
'General_LongDay_2' => 'Tirsdag',
'General_LongDay_3' => 'Onsdag',
'General_LongDay_4' => 'Torsdag',
'General_LongDay_5' => 'Fredag',
'General_LongDay_6' => 'Lørdag',
'General_LongDay_7' => 'Søndag',
'CorePluginsAdmin_Plugins' => 'Plugins',
'CorePluginsAdmin_PluginsManagement' => 'Plugin administration',
'CorePluginsAdmin_MainDescription' => 'Plugins kan udvide eller begrænse funktionaliteten i Piwik. Når et plugin er installeret, kan det aktiveres eller deaktiveres her.',
'CorePluginsAdmin_Plugin' => 'Plugin',
'CorePluginsAdmin_Version' => 'Version',
'CorePluginsAdmin_Description' => 'Beskrivelse',
'CorePluginsAdmin_Status' => 'Status',
'CorePluginsAdmin_Action' => 'Handling',
'CorePluginsAdmin_PluginHomepage' => 'Plugin hjemmeside',
'CorePluginsAdmin_Activated' => 'Aktiveret',
'CorePluginsAdmin_Active' => 'Aktiv',
'CorePluginsAdmin_Inactive' => 'Inaktiv',
'CorePluginsAdmin_ActivatedHelp' => 'Plugin kan ikke deaktiveres',
'CorePluginsAdmin_Deactivate' => 'Deaktiver',
'CorePluginsAdmin_Activate' => 'Aktiver',
'CorePluginsAdmin_MenuPlugins' => 'Plugins',
'API_QuickDocumentation' => '<h2>API - hurtig i  gang dokumentation</h2><p>Hvis du ikke har data før i \'dag\' kan du <a href=\'misc/generateVisits.php\' target=_blank>genere data</a> med besøgsgeneratoren.</p><p>Du kan prøve de forskellige formater der findes for de forskellige metoder. Det er meget let at udtrække data som ønsket fra Piwik!</p><p><b>Mere information findes på den <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiellle API dokumentation </a>side eller her <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API reference</a>.</b></P><h2>Bruger authentication</h2><p>Hvis du ønsker at <b>hente data i scripts, i crontab, m.m. </b> skal du tilføje parameteren <code><u>&token_auth=%s</u></code> til API kaldets webadresse som kræver authentication.</p><p>token_auth er ligeså hemmeligt som brugernavn og adgangskode, <b>del det ikke ud!</p>',
'API_LoadedAPIs' => '%s APIs indlæst',
'CoreHome_NoPrivileges' => 'Du er logget på som \'%s\' men det ser ikke ud som du har adgang til Piwik.<br />Spørg Piwik administrator om læseadgang.',
'CoreHome_JavascriptDisabled' => 'JavaSript skal være aktiveret for at Piwik kan bruges i standardvisning. JavaScript er enten deaktiver eller ikke understøttet i netlæseren.<br />For at bruge standardvisning, aktiver JavaScript i indstillingerne for netlæseren, og %1s prøv igen %2s.<br />',
'CoreHome_TableNoData' => 'Ingen data endnu.',
'CoreHome_CategoryNoData' => 'Ingen data i kategorien. Prøv at \'Inkluder hele populationen\'.',
'CoreHome_ShowJSCode' => 'Vis JavaScript-koden til at indsætte på websiden.',
'CoreHome_IncludeAllPopulation_js' => 'Medtag alle data',
'CoreHome_ExcludeLowPopulation_js' => 'Skjul mindste data',
'CoreHome_PageOf_js' => '%s af %s',
'CoreHome_Loading_js' => 'Indlæser...',
'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
'CoreHome_PeriodDay' => 'Dag',
'CoreHome_PeriodWeek' => 'Uge',
'CoreHome_PeriodMonth' => 'Måned',
'CoreHome_PeriodYear' => 'År',
'CoreHome_PeriodDays' => 'dage',
'CoreHome_PeriodWeeks' => 'uger',
'CoreHome_PeriodMonths' => 'måneder',
'CoreHome_PeriodYears' => 'år',
'CoreHome_DaySu_js' => 'Sø',
'CoreHome_DayMo_js' => 'Ma',
'CoreHome_DayTu_js' => 'Ti',
'CoreHome_DayWe_js' => 'On',
'CoreHome_DayTh_js' => 'To',
'CoreHome_DayFr_js' => 'Fr',
'CoreHome_DaySa_js' => 'Lø',
'CoreHome_ShortDay_1_js' => 'Søn',
'CoreHome_ShortDay_2_js' => 'Man',
'CoreHome_ShortDay_3_js' => 'Tir',
'CoreHome_ShortDay_4_js' => 'Ons',
'CoreHome_ShortDay_5_js' => 'Tor',
'CoreHome_ShortDay_6_js' => 'Fre',
'CoreHome_ShortDay_7_js' => 'Lør',
'CoreHome_LongDay_1_js' => 'Søndag',
'CoreHome_LongDay_2_js' => 'Mandag',
'CoreHome_LongDay_3_js' => 'Tirsdag',
'CoreHome_LongDay_4_js' => 'Onsdag',
'CoreHome_LongDay_5_js' => 'Torsdag',
'CoreHome_LongDay_6_js' => 'Fredag',
'CoreHome_LongDay_7_js' => 'Lørdag',
'CoreHome_ShortMonth_1_js' => 'Jan',
'CoreHome_ShortMonth_2_js' => 'Feb',
'CoreHome_ShortMonth_3_js' => 'Mar',
'CoreHome_ShortMonth_4_js' => 'Apr',
'CoreHome_ShortMonth_5_js' => 'Maj',
'CoreHome_ShortMonth_6_js' => 'Jun',
'CoreHome_ShortMonth_7_js' => 'Jul',
'CoreHome_ShortMonth_8_js' => 'Aug',
'CoreHome_ShortMonth_9_js' => 'Sep',
'CoreHome_ShortMonth_10_js' => 'Okt',
'CoreHome_ShortMonth_11_js' => 'Nov',
'CoreHome_ShortMonth_12_js' => 'Dec',
'CoreHome_MonthJanuary_js' => 'Januar',
'CoreHome_MonthFebruary_js' => 'Februar',
'CoreHome_MonthMarch_js' => 'Marts',
'CoreHome_MonthApril_js' => 'April',
'CoreHome_MonthMay_js' => 'Maj',
'CoreHome_MonthJune_js' => 'Juni',
'CoreHome_MonthJuly_js' => 'Juli',
'CoreHome_MonthAugust_js' => 'August',
'CoreHome_MonthSeptember_js' => 'September',
'CoreHome_MonthOctober_js' => 'Oktober',
'CoreHome_MonthNovember_js' => 'November',
'CoreHome_MonthDecember_js' => 'December',
'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; opdatering',
'CoreUpdater_DatabaseUpgradeRequired' => 'Database opdatering er nødvendig',
'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik databasen er ikke opdateret, og skal opgraderes før du kan fortsættes.',
'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik vil blive opgraderet fra version %s til version den nye %s.',
'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Følgende plugins vil blive opgraderet: %s.',
'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Opgraderingen kan tage lidt tid, vær tålmodig.',
'CoreUpdater_UpgradePiwik' => 'Opgrader Piwik',
'CoreUpdater_HelpMessageContent' => 'se %s Piwik FAQ %s som forklarer de mest almindelige fejl om opdateringer. %s Spørg systemadministratoren - vedkommende kan måske hjælpe med fejlen som sikkert har at skyldes server eller MySQL-installation/opsætning.',
'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritisk fejl med opdateringen:',
'CoreUpdater_HelpMessageIntroductionWhenError' => 'ovenfor vises fejlmeldingen. Den bør hjælpe med at forklare årsagen, men hvis der behøves mere hjælp:',
'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Opdateringen er fuldført, men det var nogle småproblemer under processen. Læs detaljerne ovenfor. For videre hjælp:',
'CoreUpdater_UpgradeComplete' => 'Opgradering fuldført!',
'CoreUpdater_WarningMessages' => 'Advarsler:',
'CoreUpdater_ErrorDuringPluginsUpdates' => 'Fejl under plugin opdatering:',
'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Vil automatisk deaktivere følgende plugins: %s',
'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik blev opdateret!',
'CoreUpdater_ContinueToPiwik' => 'Fortsæt til Piwik',
'CoreUpdater_UpdateAutomatically' => 'Opdater automatisk',
'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Ny version af Piwik tilgængelig for opdatering',
'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Opdater til version %s automatisk eller hent programpakken og installer manuelt:',
'CoreUpdater_DownloadX' => 'Hent %s',
'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik ét klik-opdatering er blevet annulleret. Kan ovenstående fejlmeddelelse ike løses, anbefales det at opdatere Piwik manuelt. %s Læs %sOpdaterings dokumentationen%s for at komme i gang!',
'CoreUpdate_DownloadingUpdateFromX' => 'Henter opdatering fra %s',
'CoreUpdate_UnpackingTheUpdate' => 'Opdatering pakkes ud',
'CoreUpdater_VerifyingUnpackedFiles' => 'Kontrollerer filer',
'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Backup af konfigurationfiler i %s',
'CoreUpdater_InstallingTheLatestVersion' => 'Installerer den nyeste version',
'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik er opdateret!',
'Actions_Actions' => 'Handlinger',
'Actions_SubmenuPages' => 'Sider',
'Actions_SubmenuOutlinks' => 'Udgående links',
'Actions_SubmenuDownloads' => 'Filhentninger',
'Actions_ColumnClicks' => 'Klik',
'Actions_ColumnUniqueClicks' => 'Unikke klik',
'Actions_ColumnDownloads' => 'Filhentninger',
'Actions_ColumnUniqueDownloads' => 'Unikke filhentninger',
'Actions_ColumnPageName' => 'Sidenavn',
'Actions_ColumnClickedURL' => 'Klikkede på webadresser',
'Actions_ColumnDownloadURL' => 'Download webadresser',
'Dashboard_Dashboard' => 'Kontrolpanel',
'Dashboard_AddWidget' => 'Tilføj en widget...',
'Dashboard_DeleteWidgetConfirm' => 'Bekræft fjernelse af widget fra kontrolpanelet?',
'Dashboard_SelectWidget' => 'Vælg hvilken widget som skal tilføjes kontrolpanelet.',
'Dashboard_AddPreviewedWidget_js' => 'Tilføj forhåndsvist widget til kontrolpanelet.',
'Dashboard_WidgetPreview_js' => 'Forhåndsvisning af widget',
'Dashboard_Close_js' => 'Luk',
'Dashboard_TitleWidgetInDashboard_js' => 'Widget er allerede i kontrolpanelet',
'Dashboard_TitleClickToAdd_js' => 'Klik for at tilføje til kontrolpanelet',
'Dashboard_LoadingWidget_js' => 'Indlæser Widget, vent...',
'Dashboard_WidgetNotFound_js' => 'Fandt ikke widget',
'Referers_Referers' => 'Henvisninger',
'Referers_SearchEngines' => 'Søgemaskine',
'Referers_Keywords' => ' Top søgeord',
'Referers_DirectEntry' => 'Direkte træf',
'Referers_Websites' => 'Websider',
'Referers_Campaigns' => 'Kampagner',
'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (fra %2s)',
'Referers_Evolution' => 'Udvikling over perioden',
'Referers_Type' => 'Kilde type',
'Referers_ColumnRefererType' => 'Henvisningstype',
'Referers_ColumnSearchEngine' => 'Søgemaskine',
'Referers_ColumnWebsite' => 'Websted',
'Referers_ColumnWebsitePage' => 'Websider',
'Referers_ColumnKeyword' => 'Søgeord',
'Referers_ColumnCampaign' => 'Kampagner',
'Referers_DetailsByRefererType' => 'Detaljer efter kildetype',
'Referers_TypeDirectEntries' => '%s direkte træf',
'Referers_TypeSearchEngines' => '%s fra søgemaskine',
'Referers_TypeWebsites' => '%s fra websider',
'Referers_TypeCampaigns' => '%s fra kampagner',
'Referers_Distinct' => 'Distinkte kilder efter kildetype',
'Referers_DistinctSearchEngines' => '%s distinkte søgemaskine',
'Referers_DistinctKeywords' => '%s distinkte søgeord',
'Referers_DistinctCampaigns' => 'distinkte kampagner',
'Referers_DistinctWebsites' => 'Distinkte websider ',
'Referers_UsingNDistinctUrls' => ' (bruger %2s distinkte webadresser)',
'Referers_SubmenuEvolution' => 'Udvikling',
'Referers_SubmenuSearchEngines' => 'Søgemaskine og søgeord',
'Referers_SubmenuWebsites' => 'Websider',
'Referers_SubmenuCampaigns' => 'Kampagner',
'Referers_WidgetKeywords' => 'Søgeord',
'Referers_WidgetCampaigns' => 'Kampagner',
'Referers_WidgetExternalWebsites' => 'Eksterne henvisninger',
'Referers_WidgetSearchEngines' => 'Top søgemaskine',
'Referers_WidgetOverview' => 'Oversigt',
'UserSettings_VisitorSettings' => 'Besøgendes indstillinger',
'UserSettings_BrowserFamilies' => 'Netlæsertyper',
'UserSettings_Browsers' => 'Netlæsere',
'UserSettings_Plugins' => 'Plugins',
'UserSettings_Configurations' => 'Indstillinger',
'UserSettings_OperatingSystems' => 'Styresystemer',
'UserSettings_Resolutions' => 'Opløsninger',
'UserSettings_WideScreen' => 'Widescreen',
'UserSettings_ColumnBrowserFamily' => 'Netlæsertype',
'UserSettings_ColumnBrowser' => 'Netlæser',
'UserSettings_ColumnPlugin' => 'Plugin',
'UserSettings_ColumnConfiguration' => 'Konfiguration',
'UserSettings_ColumnOperatingSystem' => 'Styresystem',
'UserSettings_ColumnResolution' => 'Opløsning',
'UserSettings_ColumnTypeOfScreen' => 'Skærmtype',
'UserSettings_WidgetResolutions' => 'Skærmopløsninger',
'UserSettings_WidgetBrowsers' => 'Netlæsere',
'UserSettings_WidgetPlugins' => 'Plugins',
'UserSettings_WidgetWidescreen' => 'Normal/Widescreen',
'UserSettings_WidgetBrowserFamilies' => 'Netlæsere efter type',
'UserSettings_WidgetOperatingSystems' => 'Styresystemer',
'UserSettings_WidgetGlobalVisitors' => 'Besøgendes konfiguration',
'UserSettings_SubmenuSettings' => 'Indstillinger',
'UserCountry_Country' => 'Land',
'UserCountry_Continent' => 'Kontinent',
'UserCountry_DistinctCountries' => '%s distinkte lande',
'UserCountry_SubmenuLocations' => 'Lokationer',
'UserCountry_WidgetContinents' => 'Kontinent',
'UserCountry_WidgetCountries' => 'Land',
'UserCountry_country_ac' => 'Ascension Islands',
'UserCountry_country_ad' => 'Andorra',
'UserCountry_country_ae' => 'Forenede Arabiske Emirater',
'UserCountry_country_af' => 'Afghanistan',
'UserCountry_country_ag' => 'Antigua og Barbuda',
'UserCountry_country_ai' => 'Anguilla',
'UserCountry_country_al' => 'Albanien',
'UserCountry_country_am' => 'Armenien',
'UserCountry_country_an' => 'Hollandske Antiller',
'UserCountry_country_ao' => 'Angola',
'UserCountry_country_aq' => 'Antarktis',
'UserCountry_country_ar' => 'Argentina',
'UserCountry_country_as' => 'Amerikansk Samoa',
'UserCountry_country_at' => 'Østrig',
'UserCountry_country_au' => 'Australien',
'UserCountry_country_aw' => 'Aruba',
'UserCountry_country_ax' => 'Aland Islands',
'UserCountry_country_az' => 'Aserbajdsjan',
'UserCountry_country_ba' => 'Bosnien-Hercegovina',
'UserCountry_country_bb' => 'Barbados',
'UserCountry_country_bd' => 'Bangladesh',
'UserCountry_country_be' => 'Belgien',
'UserCountry_country_bf' => 'Burkina Faso',
'UserCountry_country_bg' => 'Bulgarien',
'UserCountry_country_bh' => 'Bahrain',
'UserCountry_country_bi' => 'Burundi',
'UserCountry_country_bj' => 'Benin',
'UserCountry_country_bl' => 'Saint Barthelemy',
'UserCountry_country_bm' => 'Bermuda',
'UserCountry_country_bn' => 'Brunei Darussalam',
'UserCountry_country_bo' => 'Bolivia',
'UserCountry_country_br' => 'Brasilien',
'UserCountry_country_bs' => 'Bahamas',
'UserCountry_country_bt' => 'Bhutan',
'UserCountry_country_bu' => 'Burma',
'UserCountry_country_bv' => 'Bouvet-øen',
'UserCountry_country_bw' => 'Botswana',
'UserCountry_country_by' => 'Belarus',
'UserCountry_country_bz' => 'Belize',
'UserCountry_country_ca' => 'Canada',
'UserCountry_country_cc' => 'Kokos-øerne (Keeling-øerne)',
'UserCountry_country_cd' => 'Den Demokratiske Republik Congo',
'UserCountry_country_cf' => 'Centralafrikanske Republik',
'UserCountry_country_cg' => 'Congo',
'UserCountry_country_ch' => 'Schweiz',
'UserCountry_country_ci' => 'Côte d\'Ivoire (Elfenbenskysten)',
'UserCountry_country_ck' => 'Cook-øerne',
'UserCountry_country_cl' => 'Chile',
'UserCountry_country_cm' => 'Cameroun',
'UserCountry_country_cn' => 'Kina',
'UserCountry_country_co' => 'Colombia',
'UserCountry_country_cp' => 'Clipperton Island',
'UserCountry_country_cr' => 'Costa Rica',
'UserCountry_country_cs' => 'Serbien-Montenegro',
'UserCountry_country_cu' => 'Cuba',
'UserCountry_country_cv' => 'Kap Verde',
'UserCountry_country_cx' => 'Juleøen',
'UserCountry_country_cy' => 'Cypern',
'UserCountry_country_cz' => 'Tjekkiet',
'UserCountry_country_de' => 'Tyskland',
'UserCountry_country_dg' => 'Diego Garcia',
'UserCountry_country_dj' => 'Djibouti',
'UserCountry_country_dk' => 'Danmark',
'UserCountry_country_dm' => 'Dominica',
'UserCountry_country_do' => 'Dominikanske Republik',
'UserCountry_country_dz' => 'Algier',
'UserCountry_country_ea' => 'Ceuta, Melilla',
'UserCountry_country_ec' => 'Ecuador',
'UserCountry_country_ee' => 'Estland',
'UserCountry_country_eg' => 'Egypten',
'UserCountry_country_eh' => 'Vest-Sahara',
'UserCountry_country_er' => 'Eritrea',
'UserCountry_country_es' => 'Spanien',
'UserCountry_country_et' => 'Etiopien',
'UserCountry_country_eu' => 'Europæiske Union',
'UserCountry_country_fi' => 'Finland',
'UserCountry_country_fj' => 'Fiji',
'UserCountry_country_fk' => 'Falklandsøerne (Malvinerne)',
'UserCountry_country_fm' => 'Mikronesien',
'UserCountry_country_fo' => 'Færøerne',
'UserCountry_country_fr' => 'Frankrig',
'UserCountry_country_fx' => 'Fransk Metropolitan',
'UserCountry_country_ga' => 'Gabon',
'UserCountry_country_gb' => 'Storbritannien',
'UserCountry_country_gd' => 'Grenada',
'UserCountry_country_ge' => 'Grenada',
'UserCountry_country_gf' => 'Georgien',
'UserCountry_country_gg' => 'Fransk Guyana',
'UserCountry_country_gh' => 'Ghana',
'UserCountry_country_gi' => 'Gibraltar',
'UserCountry_country_gl' => 'Grønland',
'UserCountry_country_gm' => 'Gambia',
'UserCountry_country_gn' => 'Guinea',
'UserCountry_country_gp' => 'Guadeloupe',
'UserCountry_country_gq' => 'Ækvatorial Guinea',
'UserCountry_country_gr' => 'Grækenland',
'UserCountry_country_gs' => 'Syd-Georgien og Sydlige Sandwich-øer',
'UserCountry_country_gt' => 'Guatemala',
'UserCountry_country_gu' => 'Guam',
'UserCountry_country_gw' => 'Guinea-Bissau',
'UserCountry_country_gy' => 'Guyana',
'UserCountry_country_hk' => 'Hong Kong',
'UserCountry_country_hm' => 'Heard- og McDonald-øerne',
'UserCountry_country_hn' => 'Honduras',
'UserCountry_country_hr' => 'Kroatien',
'UserCountry_country_ht' => 'Haiti',
'UserCountry_country_hu' => 'Ungarn',
'UserCountry_country_ic' => 'Kanarieøerne',
'UserCountry_country_id' => 'Indonesien',
'UserCountry_country_ie' => 'Irland',
'UserCountry_country_il' => 'Israel',
'UserCountry_country_im' => 'Man Island',
'UserCountry_country_in' => 'Indien',
'UserCountry_country_io' => 'British Indian Ocean Territory',
'UserCountry_country_iq' => 'Irak',
'UserCountry_country_ir' => 'Iran',
'UserCountry_country_is' => 'Island',
'UserCountry_country_it' => 'Italien',
'UserCountry_country_je' => 'Jersey',
'UserCountry_country_jm' => 'Jamaica',
'UserCountry_country_jo' => 'Jordan',
'UserCountry_country_jp' => 'Japan',
'UserCountry_country_ke' => 'Kenya',
'UserCountry_country_kg' => 'Kirgisistan',
'UserCountry_country_kh' => 'Cambodia',
'UserCountry_country_ki' => 'Kiribati',
'UserCountry_country_km' => 'Comorerne',
'UserCountry_country_kn' => 'Sankt Kitts og Nevis',
'UserCountry_country_kp' => 'Nordkorea',
'UserCountry_country_kr' => 'Sydkorea',
'UserCountry_country_kw' => 'Kuwait',
'UserCountry_country_ky' => 'Cayman-øerne',
'UserCountry_country_kz' => 'Kasakhstan',
'UserCountry_country_la' => 'Laos',
'UserCountry_country_lb' => 'Libanon',
'UserCountry_country_lc' => 'Sankt Lucia',
'UserCountry_country_li' => 'Lichtenstein',
'UserCountry_country_lk' => 'Sri Lanka',
'UserCountry_country_lr' => 'Liberia',
'UserCountry_country_ls' => 'Lesotho',
'UserCountry_country_lt' => 'Litauen',
'UserCountry_country_lu' => 'Luxemburg',
'UserCountry_country_lv' => 'Letland',
'UserCountry_country_ly' => 'Libyen',
'UserCountry_country_ma' => 'Marokko',
'UserCountry_country_mc' => 'Monaco',
'UserCountry_country_md' => 'Moldova',
'UserCountry_country_me' => 'Montenegro',
'UserCountry_country_mf' => 'Saint Martin',
'UserCountry_country_mg' => 'Madagaskar',
'UserCountry_country_mh' => 'Marshall-øerne',
'UserCountry_country_mk' => 'Makedonien',
'UserCountry_country_ml' => 'Mali',
'UserCountry_country_mm' => 'Myanmar',
'UserCountry_country_mn' => 'Mongoliet',
'UserCountry_country_mo' => 'Macau',
'UserCountry_country_mp' => 'Nordlige Marianere',
'UserCountry_country_mq' => 'Martinique',
'UserCountry_country_mr' => 'Mauretanien',
'UserCountry_country_ms' => 'Montserrat',
'UserCountry_country_mt' => 'Malta',
'UserCountry_country_mu' => 'Mauritius',
'UserCountry_country_mv' => 'Maldiverne',
'UserCountry_country_mw' => 'Malawi',
'UserCountry_country_mx' => 'Mexico',
'UserCountry_country_my' => 'Malaysia',
'UserCountry_country_mz' => 'Mozambique',
'UserCountry_country_na' => 'Namibia',
'UserCountry_country_nc' => 'New Caledonia',
'UserCountry_country_ne' => 'Niger',
'UserCountry_country_nf' => 'Norfolk-øen',
'UserCountry_country_ng' => 'Nigeria',
'UserCountry_country_ni' => 'Nicaragua',
'UserCountry_country_nl' => 'Holland',
'UserCountry_country_no' => 'Norge',
'UserCountry_country_np' => 'Nepal',
'UserCountry_country_nr' => 'Nauru',
'UserCountry_country_nt' => 'Neutral Zone',
'UserCountry_country_nu' => 'Niue',
'UserCountry_country_nz' => 'New Zealand',
'UserCountry_country_om' => 'Oman',
'UserCountry_country_pa' => 'Panama',
'UserCountry_country_pe' => 'Peru',
'UserCountry_country_pf' => 'Fransk Polynesien',
'UserCountry_country_pg' => 'Papua New Guinea',
'UserCountry_country_ph' => 'Philippinerne',
'UserCountry_country_pk' => 'Pakistan',
'UserCountry_country_pl' => 'Polen',
'UserCountry_country_pm' => 'Sankt Pierre og Miquelon',
'UserCountry_country_pn' => 'Pitcairn',
'UserCountry_country_pr' => 'Puerto Rico',
'UserCountry_country_ps' => 'Palæstina',
'UserCountry_country_pt' => 'Portugal',
'UserCountry_country_pw' => 'Palau-øerne',
'UserCountry_country_py' => 'Paraguay',
'UserCountry_country_qa' => 'Qatar',
'UserCountry_country_re' => 'Réunion',
'UserCountry_country_ro' => 'Rumænien',
'UserCountry_country_ru' => 'Russiske Føderation',
'UserCountry_country_rs' => 'Serbien',
'UserCountry_country_rw' => 'Rwanda',
'UserCountry_country_sa' => 'Saudi-Arabien',
'UserCountry_country_sb' => 'Salomon-øerne',
'UserCountry_country_sc' => 'Seychellerne',
'UserCountry_country_sd' => 'Sudan',
'UserCountry_country_se' => 'Sverige',
'UserCountry_country_sf' => 'Finland',
'UserCountry_country_sg' => 'Singapore',
'UserCountry_country_sh' => 'Sankt Helena',
'UserCountry_country_si' => 'Slovenien',
'UserCountry_country_sj' => 'Svalbard og Jan Mayen',
'UserCountry_country_sk' => 'Slovakiet',
'UserCountry_country_sl' => 'Sierra Leone',
'UserCountry_country_sm' => 'San Marino',
'UserCountry_country_sn' => 'Senegal',
'UserCountry_country_so' => 'Somalia',
'UserCountry_country_sr' => 'Suriname',
'UserCountry_country_st' => 'São Tomé og Príncipe',
'UserCountry_country_su' => '[Russiske Føderation]',
'UserCountry_country_sv' => 'El Salvador',
'UserCountry_country_sy' => 'Syrien',
'UserCountry_country_sz' => 'Swaziland',
'UserCountry_country_ta' => 'Tristan da Cunha',
'UserCountry_country_tc' => 'Turks- og Caicos-øerne',
'UserCountry_country_td' => 'Chad',
'UserCountry_country_tf' => 'Franske Sydlige Territorier',
'UserCountry_country_tg' => 'Togo',
'UserCountry_country_th' => 'Thailand',
'UserCountry_country_tj' => 'Tadsjikistan',
'UserCountry_country_tk' => 'Tokelau',
'UserCountry_country_tl' => 'Øst-Timor',
'UserCountry_country_tm' => 'Turkmenistan',
'UserCountry_country_tn' => 'Tunesien',
'UserCountry_country_to' => 'Tonga',
'UserCountry_country_tp' => 'Øst-Timor',
'UserCountry_country_tr' => 'Tyrkiet',
'UserCountry_country_tt' => 'Trinidad og Tobago',
'UserCountry_country_tv' => 'Tuvalu',
'UserCountry_country_tw' => 'Taiwan',
'UserCountry_country_tz' => 'Tanzania',
'UserCountry_country_ua' => 'Ukraine',
'UserCountry_country_ug' => 'Uganda',
'UserCountry_country_uk' => 'England',
'UserCountry_country_um' => 'Forenede Staters Mindre Perifere',
'UserCountry_country_us' => 'Amerikas Forenede Stater (USA)',
'UserCountry_country_uy' => 'Uruguay',
'UserCountry_country_uz' => 'Usbekistan',
'UserCountry_country_va' => 'Vatikanstaten',
'UserCountry_country_vc' => 'Sankt Vincent og Grenadinerne',
'UserCountry_country_ve' => 'Venezuela',
'UserCountry_country_vg' => 'Jomfruøerne, Engelsk',
'UserCountry_country_vi' => 'Jomfruøerne, USA',
'UserCountry_country_vn' => 'Viet Nam',
'UserCountry_country_vu' => 'Vanuatu',
'UserCountry_country_wf' => 'Wallis- og Futuna-øerne',
'UserCountry_country_ws' => 'Samoa',
'UserCountry_country_ye' => 'Yemen',
'UserCountry_country_yt' => 'Mayotte',
'UserCountry_country_yu' => 'Jugoslavien (Serbien og Montenegro)',
'UserCountry_country_za' => 'Sydafrikanske Republik',
'UserCountry_country_zm' => 'Zambia',
'UserCountry_country_zr' => 'Zaire [Den Demokratiske Republik',
'UserCountry_country_zw' => 'Zimbabwe',
'UserCountry_continent_eur' => 'Europa',
'UserCountry_continent_afr' => 'Afrika',
'UserCountry_continent_asi' => 'Asien',
'UserCountry_continent_ams' => 'Syd- og Centralamerika',
'UserCountry_continent_amn' => 'Nordamerika',
'UserCountry_continent_oce' => 'Oceanien',
'VisitsSummary_NbVisits' => '%s besøg',
'VisitsSummary_NbUniqueVisitors' => '%s unikke besøgende',
'VisitsSummary_NbActions' => '%s handlinger (sidevisninger)',
'VisitsSummary_TotalTime' => '%s samlet tid brugt af besøgende',
'VisitsSummary_MaxNbActions' => '%s maks. handlinger i ét besøg',
'VisitsSummary_NbVisitsBounced' => '%s har forladt websted efter én sidevisning',
'VisitsSummary_EvolutionOverLastPeriods' => 'Udvikling de sidste %s',
'VisitsSummary_Report' => 'Rapport',
'VisitsSummary_GenerateTime' => 'Siden generedes på %s sek.',
'VisitsSummary_GenerateQueries' => '%s forespørgelser kørt',
'VisitsSummary_WidgetLastVisits' => 'Seneste besøg',
'VisitsSummary_WidgetVisits' => 'Besøgsoversigt',
'VisitsSummary_WidgetLastVisitors' => 'Seneste unikke besøgende',
'VisitsSummary_WidgetOverviewGraph' => 'Oversigt med grafik',
'VisitsSummary_SubmenuOverview' => 'Oversigt',
'VisitFrequency_Evolution' => 'Udvikling i perioden',
'VisitFrequency_ColumnReturningVisits' => 'Tilbagevendende besøg',
'VisitFrequency_ColumnActionsByReturningVisits' => 'Handlinger af tilbagevendene besøg',
'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Max antal handlinger af tilbagevendene besøg',
'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Samlet tid brugt af tilbagevendene besøg (i sekunder)',
'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Afvisningsfrekvens for tilbagevendene besøg',
'VisitFrequency_ReturnVisits' => '%s tilbagevendende besøg',
'VisitFrequency_ReturnActions' => '%s handlinger af de tilbagevendende besøg',
'VisitFrequency_ReturnMaxActions' => '%s maks. handlinger af de tilbagevendende besøg',
'VisitFrequency_ReturnTotalTime' => '%s total tid brugt af de tilbagevendende besøg',
'VisitFrequency_ReturnBounceRate' => '%s tilbagevendende besøg har forladt siden efter en sidevisning.',
'VisitFrequency_WidgetOverview' => 'Hyppighedsoversigt',
'VisitFrequency_WidgetGraphReturning' => 'Tilbagevendende besøg',
'VisitFrequency_SubmenuFrequency' => 'Hyppighed',
'VisitTime_LocalTime' => 'Besøg pr. lokaltid',
'VisitTime_ServerTime' => 'Besøg pr. servertid',
'VisitTime_ColumnServerTime' => 'Servertid',
'VisitTime_ColumnLocalTime' => 'Lokaltid',
'VisitTime_WidgetLocalTime' => 'Besøg (lokaltid)',
'VisitTime_WidgetServerTime' => 'Besøg (servertid)',
'VisitTime_SubmenuTimes' => 'Tider',
'VisitTime_NHour' => '%s',
'VisitorInterest_VisitsPerDuration' => 'Tid pr. besøg',
'VisitorInterest_VisitsPerNbOfPages' => 'Besøg pr. antal sider',
'VisitorInterest_ColumnVisitDuration' => 'Besøgslængde',
'VisitorInterest_ColumnPagesPerVisit' => 'Sider pr. besøg',
'VisitorInterest_WidgetLengths' => 'Besøgslængde',
'VisitorInterest_WidgetPages' => 'Sidevisninger pr. besøg',
'VisitorInterest_SubmenuFrequencyLoyalty' => 'Hyppighed og loyalitet',
'VisitorInterest_PlusXMin' => '%s min.',
'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min.',
'VisitorInterest_OnePage' => '1 side',
'VisitorInterest_NPages' => '%s sider',
'VisitorInterest_BetweenXYSeconds' => '%1s-%2 sek.',
'Login_LoginPasswordNotCorrect' => 'Brugernavn og adgangskode er ikke korrekt',
'Login_Login' => 'Brugernavn',
'Login_Password' => 'Adgangskode',
'Login_LoginOrEmail' => 'Brugernavn eller e-mailadresse',
'Login_LogIn' => 'Log på',
'Login_Logout' => 'Log af',
'Login_LostYourPassword' => 'Glemt adgangskode?',
'Login_RemindPassword' => 'Husk adgangskode',
'Login_PasswordReminder' => 'Skriv dit brugernavn eller e-mailadresse. Du vil modtage en ny adgangskode med e-mail.',
'Login_InvalidUsernameEmail' => 'Fejl i brugernavn og/eller e-mailadresse.',
'Login_MailTopicPasswordRecovery' => 'Genopret adgangskode',
'Login_MailPasswordRecoveryBody' => 'Hej %1s, \n\m Ny adgangskode er: %2s \n\n Du kan logge på her: %3s',
'Login_PasswordSent' => 'Adgangskoden er sendt. Tjek din e-mail.',
'Login_ContactAdmin' => 'Mulig grund: udbyderen har måske deaktiveret mail()-funktionen. <br />Kontakt Piwik administrator.',
'UsersManager_UsersManagement' => 'Bruger administration',
'UsersManager_UsersManagementMainDescription' => 'Opret nye brugere eller opdater eksisterende. Efterfølgende kan tilladelser ændres.',
'UsersManager_ManageAccess' => 'Administrer adgang',
'UsersManager_MainDescription' => 'Bestem hvilken bruger der har adgang til Piwik på websiderne. Adgang kan også sættes på alle websider på en gang.',
'UsersManager_Sites' => 'Websteder',
'UsersManager_AllWebsites' => 'Alle websteder',
'UsersManager_ApplyToAllWebsites' => 'Tilføj til alle websteder',
'UsersManager_User' => 'Bruger',
'UsersManager_PrivNone' => 'Ingen adgang',
'UsersManager_PrivView' => 'Vis',
'UsersManager_PrivAdmin' => 'Admin',
'UsersManager_ChangeAllConfirm' => 'Bekræft ændring \'%s\' adgang på alle websiderne?',
'UsersManager_Login' => 'Log på',
'UsersManager_Password' => 'Adgangskode',
'UsersManager_Email' => 'E-mail',
'UsersManager_Alias' => 'Alias',
'UsersManager_Edit' => 'Ændre',
'UsersManager_AddUser' => 'Opret ny bruger',
'UsersManager_MenuUsers' => 'Brugere',
'UsersManager_DeleteConfirm_js' => 'Bekræft sletning af bruger %s?',
'UsersManager_ExceptionLoginExists' => 'Brugernavn \'%s\' eksisterer allerede.',
'UsersManager_ExceptionEmailExists' => 'Bruger med e-mail \'%s\' eksisterer allerede.',
'UsersManager_ExceptionInvalidLoginFormat' => 'Brugernavn kan kun indeholde bogstaver, tal og tegnene \'_\' eller \'-\' eller \'.\'',
'UsersManager_ExceptionInvalidPassword' => 'Længden på adgangskoden skal være mellem 6 og 26 tegn.',
'UsersManager_ExceptionInvalidEmail' => 'E-mailadressen er ikke i gyldig format.',
'UsersManager_ExceptionDeleteDoesNotExist' => 'Bruger \'%s\' eksisterer ikke, og kan derfor ikke  slettes.',
'UsersManager_ExceptionAdminAnonymous' => 'Administrator-adgang kan ikke gives til \'anonyme\'-bruger.',
'UsersManager_ExceptionEditAnonymous' => 'Anonyme brugere kan ikke redigeres eller slettet. Anvendes af Piwik til at definere en bruger, som ikke er blevet logget på endnu. For eksempel kan du gøre din statistik offentlig ved at give  \'se\' adgang til \'anonym\' bruger', 
'UsersManager_ExceptionSuperUser' => 'Anmodede bruger er Superbrugeren og kan ikke  forespørges, rettes eller slettes gennem API. Kan rettes manuelt under Superbruger detaljer i  Piwik konfigurationsfilen.',
'UsersManager_ExceptionUserDoesNotExist' => 'Bruger \'%s\' findes ikke.',
'UsersManager_ExceptionAccessValues' => 'Parameteren skal have en af de følgende værdier: [ %s ]',
'SitesManager_Sites' => 'Websteder',
'SitesManager_WebsitesManagement' => 'Administration af websteder',
'SitesManager_MainDescription' => 'Analyser behøver websteder! Tilføj, opdater, slet websteder, og vis JavaScriptkoden som skal tilføjes webstederne.',
'SitesManager_JsTrackingTag' => 'JavaScript sporingskode',
'SitesManager_JsTrackingTagHelp' => 'JavaScript-sporingskoden som skal tilføjes til alle sider',
'SitesManager_ShowTrackingTag' => 'vis sporingskode',
'SitesManager_NoWebsites' => 'Der er ingen websteder at administrere',
'SitesManager_AddSite' => 'Tilføj et nyt websted',
'SitesManager_Id' => 'ID',
'SitesManager_Name' => 'Navn',
'SitesManager_Urls' => 'Webadresser',
'SitesManager_MenuSites' => 'Websteder',
'SitesManager_DeleteConfirm_js' => 'Bekræft sletning af følgende websted? %s',
'SitesManager_ExceptionDeleteSite' => 'Det er ikke muligt at slette webstedet, da det er det eneste oprettede websted. Tilføj et nyt websted, og slet så dette .',
'SitesManager_ExceptionNoUrl' => 'Angiv mindst én webadresse til webstedet.',
'SitesManager_ExceptionEmptyName' => 'Webstedets navn kan ikke være tomt.',
'SitesManager_ExceptionInvalidUrl' => 'Webadressen \'%s\' er ikke gyldig.',
'Installation_Installation' => 'Installation',
'Installation_InstallationStatus' => 'Installationstatus',
'Installation_PercentDone' => '%s %% udført',
'Installation_NoConfigFound' => 'Piwik-konfigurationsfil blev ikke fundet og du prøver at få adgang til Piwik. <br /><b>&nbsp;&nbsp;&raquo;Du kan <a href=\'index.php\'>installere Piwik nu</a></b><br /><small> Hvis du har installeret Piwik tidliger og har nogle tabeller i databasen, kan du genbruge tabellerne og holde dine eksisterende data!</small>',
'Installation_MysqlSetup' => 'MySQL database oprettet',
'Installation_MysqlErrorConnect' => 'Fejl ved tilkobling til databasen',
'Installation_JsTag' => 'JavaScript kode',
'Installation_JsTagHelp' => '<p>For at tælle alle besøgende, indsættes JavaScript-koden på alle sider.</p><p>Siderne behøver ikke være lavet med PHP, Piwik vil virke på alle typer sider (uanset om det er HTML, ASP, Perl eller et andet sprog).</p><p>Her er koden der skal indsættes: (kopier og indsæt på alle sider)</p>',
'Installation_Congratulations' => 'Tillykke',
'Installation_CongratulationsHelp' => '<p>Tillykke! Piwik installationen er færdig.</p><p>Sørg for at JavaScript-koden er tilføjet på  dine sider, og vent på de første besøgende!</p>',
'Installation_ContinueToPiwik' => 'Fortsæt til Piwik',
'Installation_SetupWebsite' => 'Tilføj et websted',
'Installation_SetupWebsiteError' => 'Fejl ved tilføjelse af websted',
'Installation_GeneralSetup' => 'Generel opsætning',
'Installation_GeneralSetupSuccess' => 'Generel opsætning gemt',
'Installation_SuperUserLogin' => 'superbruger log på',
'Installation_Password' => 'adgangskode',
'Installation_PasswordRepeat' => 'gentag adgangskode',
'Installation_Email' => 'e-mail',
'Installation_SecurityNewsletter' => 'Send e-mail med vigtige Piwik opgraderinger og sikkerheds advarsler',
'Installation_CommunityNewsletter' => 'Send e-mail med opdateringer (nye plugins, nye muligheder m.m.)',
'Installation_PasswordDoNotMatch' => 'adgangskoder stemmer ikke overens',
'Installation_SubmitGo' => 'Kør!',
'Installation_SystemCheck' => 'Systemcheck',
'Installation_SystemCheckPhp' => 'PHP version',
'Installation_SystemCheckPdo' => 'Pdo udvidelse',
'Installation_SystemCheckPdoMysql' => 'Pdo_MySql udvidelse',
'Installation_SystemCheckPdoError' => 'Aktivere PDO og PDO_MYSQL i php.ini filen.',
'Installation_SystemCheckPdoHelp' => 'På en Windows-server tilføj følgende linjer til php-ini %s <br /><br />På en linux-server kompilere php med følgende valg %s I php.ini, tilføj følgende linjer %s<br /><br />Mere information findes på <a style=\'color:red\' href=\'http://php.net/pdo\'>PHP.net</a>.',
'Installation_SystemCheckWriteDirs' => 'Mapper med skriveadgang',
'Installation_SystemCheckWriteDirsHelp' => 'Prøv at skrive følgende kommandoer for at rette fejlen på et linux-system',
'Installation_SystemCheckMemoryLimit' => 'Hukommelses grænse',
'Installation_SystemCheckMemoryLimitHelp' => 'På et stærkt trafikeret websted, kan arkiveringsprocessen kræve mere hukommelse end der er tilladt.<br />Se på memory_limit i php.ini filen hvis nødvendig.',
'Installation_SystemCheckGD' => 'GD &gt; 2.x (grafik)',
'Installation_SystemCheckGDHelp' => 'Mindre grafiske elementer vil ikke fungere som ønsket.',
'Installation_SystemCheckTimeLimit' => 'set_time_limit() tilladt',
'Installation_SystemCheckTimeLimitHelp' => 'På et stærkt trafikeret websted, kan arkiveringsprocessen kræve mere tid end der tilladt.<br />Se på max_execution_time i php.ini filen hvis nødvendig.',
'Installation_SystemCheckMail' => 'mail() tilgængelig',
'Installation_SystemCheckError' => 'En fejl opstod - skal rettes før der kan fortsættes',
'Installation_SystemCheckWarning' => 'Piwik vil virke normalt, men nogle funktioner vil måske mangle',
'Installation_Tables' => 'Opretter tabeller',
'Installation_TablesWithSameNamesFound' => 'Nogle %s tabeller i databasen %s har samme navn, som dem Piwik prøver at oprette',
'Installation_TablesFound' => 'Følgende tabeller blev fundet i databasen',
'Installation_TablesWarningHelp' => 'Vælg enten at genbruge de eksisterende tabeller eller vælg en ren installation for at slette alle eksisterende data.',
'Installation_TablesReuse' => 'Genbrug de eksisterende tabeller',
'Installation_TablesDelete' => 'Slet detekterede tabeller',
'Installation_TablesDeletedSuccess' => 'Eksisterende Piwik-tabeller blev slettet',
'Installation_TablesCreatedSuccess' => 'Tabellerne blev oprettet!',
'Installation_DatabaseCreatedSuccess' => 'Databasen %s blev oprettet!',
'Installation_GoBackAndDefinePrefix' => 'Gå tilbage og  opret prefix for Piwik Tabeller',
'Installation_ConfirmDeleteExistingTables' => 'Bekræft sletning af tabellerne: %s fra databasen? ADVARSEL: DATA FRA DISSE TABELLER KAN IKKE GENSKABES!',
'Installation_Welcome' => 'Velkommen!',
'Installation_WelcomeHelp' => '<p>Piwik er et Open Source statistik-program som gør det enkelt at finde information om besøgende.</p><p> Processen er delt op i %s lette trin og vil tage ca. 5 minutter.</p>',
'Installation_ErrorInvalidState' => 'Fejl: Det lader til at du forsøger at springe et skridt af installationen over, eller cookies er slået fra, eller Piwik opsætningsfil  allerede er oprettet. %sSørg for, at cookies er aktiveret%s og gå tilbage%s til den første side i installationen%s. ',
'Provider_WidgetProviders' => 'Udbydere',
'Provider_ColumnProvider' => 'Udbyder',
'Provider_SubmenuLocationsProvider' => 'Sted og udbyder',
'Goals_ColumnConversions' => 'Omregninger',
'Goals_ColumnConversionRate' => 'Omregnings frekvens',
'Goals_ColumnRevenue' => 'Indtægter',
'DBStats_DatabaseUsage' => 'Databasebrug',
'DBStats_MainDescription' => 'Piwik gemmer al statistik i MySQL-databasen. Lige nu bruger Piwik-tabellen %s.',
'DBStats_Table' => 'Tabel',
'DBStats_RowNumber' => 'Antal rækker',
'DBStats_DataSize' => 'Data',
'DBStats_IndexSize' => 'Index',
'DBStats_TotalSize' => 'Samlet størrelse',
'TranslationsAdmin_MenuTranslations' => 'Oversættelser',
'TranslationsAdmin_MenuLanguages' => 'Sprog',
'TranslationsAdmin_Plugin' => 'Plugin',
'TranslationsAdmin_Definition' => 'Definition',
'TranslationsAdmin_DefaultString' => 'Standard (English)',
'TranslationsAdmin_TranslationString' => 'Oversættelse (gældende sprog: %s)',
'TranslationsAdmin_Translations' => 'Oversættelser',
'TranslationsAdmin_FixPermissions' => 'Ret filsystem-rettighederne',
'TranslationsAdmin_AvailableLanguages' => 'Tilgængelige sprog',
'TranslationsAdmin_AddLanguage' => 'Tilføj sprog',
'TranslationsAdmin_LanguageCode' => 'Sprogkode',
'TranslationsAdmin_Export' => 'Eksporter sprog',
'TranslationsAdmin_Import' => 'Importer sprog',
);
